Learn R Programming

FlowCAr (version 1.1.1)

FlowCAr: Flow Network Construction and Analysis

Description

This package allows for the creation of multiple possible network models based on a single FlowCAr input file.

Arguments

Details

The following table indicates the functions used in the FlowCAr package.

Procedure FlowCAr Functions
- -
Network Construction LIMbuild
limListGen
flowCheck
flowLimit
Restructuring and Packing inputVector
exportVector
respVector
outputVector
biomassVector
livingVector
PackNet
Main Function enaListGen
Network Validation and Visualisation plotNodeFlows
plotRange
plotFlowRange